@@ -60,7 +60,7 @@ locale.setlocale(locale.LC_ALL, "")
 PATTERN = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
 PATTERN_TITLE = '%(asctime)s | %(message)s'
 
-HAS_PIPX = True if shutil.which('pipx') else False
+HAS_PIPX = bool(shutil.which('pipx'))
 
 try:
     import netifaces
@@ -81,7 +81,7 @@ except:
 class MyArgParser(ArgumentParser):
 
     def __init(self):
-        super(MyArgParser, self).__init__(
+        super().__init__(
             description = description
         )
 
@@ -313,7 +313,13 @@ If nothing else works, try the following command:
     pl_group.add_argument('-ls', '--list-playlists', action='store_true',
                         help='List of available playlists in config dir.')
     pl_group.add_argument('-s', '--stations', default='', metavar=('PLAYLIST', ),
-                        help='Load the specified playlist instead of the default one.')
+                        help='Load the specified playlist instead of the default one.'
+                          ' PLAYLIST can be the path to a CSV or an M3U file, '
+                          'the name (without extension) of a CSV or an M3U file '
+                          'which is in the station\'s folder, or the number which '
+                          'corresponds to a file presented at the output of the '
+                          '-ls command line parameter.'
+                          )
     pl_group.add_argument('-tlp', '--toggle-load-last-playlist', action='store_true',
                         help='Toggle autoload last opened playlist.')
 
@@ -724,10 +730,10 @@ If nothing else works, try the following command:
             return
 
         if args.show_themes:
-            int_themes = [x for x in pyradio_config.internal_themes if x != 'wob' and x != 'bow']
+            int_themes = [x for x in pyradio_config.internal_themes if x not in ('wob', 'bow')]
             sys_themes = list(pyradio_config.system_themes)
             user_themes = glob.glob(path.join(pyradio_config.themes_dir, '*.pyradio-theme'))
-            for i in range(0, len(user_themes)):
+            for i, _ in enumerate(user_themes):
                 user_themes[i] = path.basename(user_themes[i]).replace('.pyradio-theme', '')
 
             # remove project themes names from user_themes
@@ -794,11 +800,11 @@ If nothing else works, try the following command:
             if pyradio_config.locked:
                 print_session_is_locked()
                 return
-            else:
-                pyradio_config.opts['open_last_playlist'][1] = not pyradio_config.opts['open_last_playlist'][1]
-                pyradio_config.opts['dirty_config'][1] =  True
-                print(f"Setting auto load last playlist to: \"[red]{pyradio_config.opts['open_last_playlist'][1]}[/red]\"")
-                save_config()
+
+            pyradio_config.opts['open_last_playlist'][1] = not pyradio_config.opts['open_last_playlist'][1]
+            pyradio_config.opts['dirty_config'][1] =  True
+            print(f"Setting auto load last playlist to: \"[red]{pyradio_config.opts['open_last_playlist'][1]}[/red]\"")
+            save_config(pyradio_config)
             return
 
         package = 0
@@ -1194,6 +1200,7 @@ that window to complete the update process.''')
                 process.wait()
                 pyradio.play = 'False'
                 pyradio.stopPlayer()
+                pyradio_config.USE_EXTERNAL_PLAYER = False
             else:
                 break
 
@@ -1398,10 +1405,8 @@ def open_conf_dir(cnf, msg=None, a_dir=None):
 def get_format_string(stations):
     len0 = len1 = 0
     for n in stations:
-        if cjklen(n[0]) > len0:
-            len0 = cjklen(n[0])
-        if cjklen(n[1]) > len1:
-            len1 = cjklen(n[1])
+        len0 = max(cjklen(n[0]), len0)
+        len1 = max(cjklen(n[1]), len1)
     num = len(str(len(stations)))
     # format_string = '{0:>' + str(num) + '.' + str(num) + 's}. ' + '{1:' + str(len0) + '.' + str(len0) + 's} | {2:' + str(len1) + '.' + str(len1) + 's} | {3}'
     format_string = '{0:>' + str(num) + '.' + str(num) + 's}. ' + '{1} | {2:' + str(len1) + '.' + str(len1) + 's} | {3}'
@@ -1461,12 +1466,12 @@ def csv_vs_m3u_output_filename(input_file, output_dir, resource_type="csv"):
         return full_path
 
     def _detect_input_type(filename):
-        basename = path.basename(filename)
-        if basename.lower().endswith('.csv'):
+        basename = path.basename(filename).lower()
+        if basename.endswith('.csv'):
             return 'csv'
-        elif basename.lower().endswith('.m3u'):
+        if basename.endswith('.m3u'):
             return 'm3u'
-        elif basename.lower().endswith('.m3u8'):
+        if basename.endswith('.m3u8'):
             return 'm3u'
         return None
 
