@@ -58,7 +58,7 @@ def is_light_or_dark(rgb_color=None):
     hsp = sqrt(0.241 * (r * r) + 0.691 * (g * g) + 0.068 * (b * b))
     # logger.error('hsp = {}'.format(hsp))
 
-    return True if hsp > 130 else False
+    return hsp > 130
 
 def calculate_fifteenth_color(colors, an_amount, inhibit_if_color15_exists=True):
     if an_amount == '0' or \
@@ -408,7 +408,7 @@ class PyRadioTheme():
         if logger.isEnabledFor(logging.DEBUG):
             logger.debug('Recalculating color15...')
             logger.debug(f"Stations background color: {self._colors['css'][2]}")
-        self._cnf.use_calculated_colors = False if self._cnf.opts['calculated_color_factor'][1] == '0' else True
+        self._cnf.use_calculated_colors = not self._cnf.opts['calculated_color_factor'][1] == '0'
         # logger.error('\n\nself._colors before recalculate\n{}\n\n'.format(self._colors))
         if self._colors['color_factor'] == 0:
             fact = self._cnf.opts['calculated_color_factor'][1]
@@ -447,7 +447,7 @@ class PyRadioTheme():
             # print(self._colors)
             if ret == 0:
                 return True, f'Theme created: "{out_theme_name}"'
-            elif ret == -2:
+            if ret == -2:
                 return False, f'Error writing theme file: "{out_theme_name}"'
         else:
             ''' copy theme file '''
@@ -637,7 +637,6 @@ class PyRadioTheme():
         ]
         # logger.error(f'{theme_dirs = }')
 
-
         # Search in user dir firts
         for theme_dir, is_package_resource in theme_dirs_to_search:
             # Case 1: It is Traversable (package source)
@@ -1175,7 +1174,7 @@ class PyRadioThemeSelector():
     def _short_to_normal_theme_name(self, a_theme_name):
         if a_theme_name == 'bow':
             return 'black_on_white'
-        elif a_theme_name == 'wob':
+        if a_theme_name == 'wob':
             return 'white_on_black'
         return a_theme_name
 
@@ -1481,7 +1480,7 @@ class PyRadioThemeSelector():
         if char in (kbkey['edit'], ) or \
                 check_localized(char, (kbkey['edit'], )):
             ''' edit theme '''
-            pass
+            # not implemented yet
             # if self._themes[self._selection][1] == '' or \
             #         self._is_theme_read_only(self._themes[self._selection][1]):
             #     ''' display question to create theme instead '''
@@ -1491,7 +1490,7 @@ class PyRadioThemeSelector():
         elif char in (kbkey['add'], ) or \
                 check_localized(char, (kbkey['add'], )):
             ''' new theme '''
-            pass
+            # not implemented yet
         elif char == kbkey['reload'] or \
                 check_localized(char, (kbkey['reload'], )):
             return -4, False
